import{n as N,q as m,v as o,w,x as p,T as h,y as x,z as u,A as i,R as y,B as A,C,D as R,E as D}from"./CG4Mcn_E.js";function g(r){var a=N("template");return a.innerHTML=r.replaceAll("<!>","<!---->"),a.content}function t(r,a){var e=p;e.nodes===null&&(e.nodes={start:r,end:a,a:null,t:null})}function L(r,a){var e=(a&h)!==0,l=(a&x)!==0,s,_=!r.startsWith("<!>");return()=>{if(u)return t(i,null),i;s===void 0&&(s=g(_?r:"<!>"+r),e||(s=o(s)));var n=l||w?document.importNode(s,!0):s.cloneNode(!0);if(e){var v=o(n),d=n.lastChild;t(v,d)}else t(n,n);return n}}function M(r,a,e="svg"){var l=!r.startsWith("<!>"),s=(a&h)!==0,_=`<${e}>${l?r:"<!>"+r}</${e}>`,n;return()=>{if(u)return t(i,null),i;if(!n){var v=g(_),d=o(v);if(s)for(n=document.createDocumentFragment();o(d);)n.appendChild(o(d));else n=o(d)}var f=n.cloneNode(!0);if(s){var E=o(f),T=f.lastChild;t(E,T)}else t(f,f);return f}}function P(r,a){return M(r,a,"svg")}function b(r=""){if(!u){var a=m(r+"");return t(a,a),a}var e=i;return e.nodeType!==C?(e.before(e=m()),R(e)):D(e),t(e,e),e}function F(){if(u)return t(i,null),i;var r=document.createDocumentFragment(),a=document.createComment(""),e=m();return r.append(a,e),t(a,e),r}function S(r,a){if(u){var e=p;((e.f&y)===0||e.nodes.end===null)&&(e.nodes.end=i),A();return}r!==null&&r.before(a)}const O="5";var c;typeof window<"u"&&((c=window.__svelte??(window.__svelte={})).v??(c.v=new Set)).add(O);export{S as a,t as b,F as c,g as d,P as e,L as f,b as t};
